@@ -427,6 +427,47 @@ int open_net(const char *pathname, int flags, mode_t mode) {
 }
 
 
+ssize_t read_net(int fd, void *buf, size_t count) {
+	ssize_t retval = -1;
+	ssize_t read_ret;
+	int socket = 0;
+#ifdef HAVE_GETPEERNAME
+	int gpn_ret;
+	struct sockaddr_in *tmp = NULL;
+	int tmplen;
+
+	tmplen = sizeof(tmp);
+
+	gpn_ret = getpeername(fd, (struct sockaddr *) tmp, &tmplen);
+
+	if (gpn_ret >= 0) {
+		socket = 1;
+	}
+#endif
+
+	while (count) {
+		if (socket) {
+			read_ret = recv(fd, buf, count, 0);
+		} else {
+			read_ret = read(fd, buf, count);
+		}
+
+		if (read_ret == 0) {
+			break;
+		}
+
+		if (read_ret < 0) {
+			retval = read_ret;
+			break;
+		}
+
+		count -= read_ret;
+		buf += read_ret;
+	}
+
+	return(retval);
+}
+
 off_t lseek_net(int filedes, off_t offset, int whence) {
 	return(-1);
 }
